<?php
/**
 * @version			2.2.0
 * @author			Nicholas G. Antimisiaris
 * @authoremail		nant@joomlapolis.com
 * @authorurl		www.joomlapolis.com
 * @package			Joomla 2 CiviCRM User Sync
 * @file			civicrmactivitytypelist.php
 * @copyright		Copyright (C) 2013-2019. All rights reserved
 * @license			GNU GPL version 2
 * @description		Code used by Joomla plugin parameter form to grab information from CiviCRM installation
 * 					action types from CiviCRM are read and presented as a single-select list for admin to
 * 					specify what action type to use. Activity types are filtered for contact component only
 * 					and can only be assigned to a single contact id or not assigned at all.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

jimport('joomla.form.formfield');
jimport('joomla.form.helper');
JFormHelper::loadFieldClass('list');

class JFormFieldcivicrmactivitytypelist extends JFormFieldList
{
	protected $type = 'civicrmactivitytypelist';

	/**
 	* Method to get the field options.
 	*
 	* @return  array  The field option objects.
 	*
 	* @since   11.1
 	*/
	protected function getOptions()
	{
		// Initialize variables.
		$options = array();
		if (!file_exists(JPATH_ROOT . '/administrator/components/com_civicrm/helpers/api.php')) {

			// CiviCRM Joomla component not installed so just specify single option notice

			$j2c_tmp = JHtml::_(
				'select.option', (string) 'CiviCRM not installed',
				JText::alt(trim((string) 0), preg_replace('/[^a-zA-Z0-9_\-]/', '_', $this->fieldname)),
				'value', 'text',
				((string) false)
			);

			$j2c_tmp->class = (string) '';
			$j2c_tmp->onclick = (string) '';

			$options[] = $j2c_tmp;

		} else {

			// CiviCRM Joomla component exists so go ahead and grab location types using api

			require_once JPATH_ROOT . '/administrator/components/com_civicrm/helpers/api.php';
			CivicrmHelperApi::civiimport('api');


			$params = array(
				'name'		=> 'activityType',
				'version'	=> 3
			);


			$j2c_system_activity_types = civicrm_api('constant','get', $params);


			$j2c_activitytypes = $j2c_system_activity_types['values'];
			$j2c_activitytypekeys = array_keys($j2c_activitytypes);
			$j2c_keycount = count($j2c_activitytypekeys);

			for ($j2c_key=0; $j2c_key<$j2c_keycount; $j2c_key++) {

				$j2c_lockey = $j2c_activitytypekeys[$j2c_key];
				$j2c_locval = $j2c_activitytypes[$j2c_lockey];

				$params = array(
					'version'	=> 3,
					'sequential'	=> 1,
					'option_group_name'	=> 'activity_type',
					'value'	=> $j2c_lockey
				);
				$j2c_oneactivitytype = civicrm_api('OptionValue', 'get', $params);

				if ( $j2c_oneactivitytype['is_error'] || isset($j2c_oneactivitytype['values'][0]['component_id']) ) {
					// if activity type previously found does have a component_id then ignore as
					// we only want the contact component types

					continue;
				}


				$j2c_tmp = JHtml::_(
					'select.option', (string) $j2c_lockey,
					JText::alt(trim((string) $j2c_locval), preg_replace('/[^a-zA-Z0-9_\-]/', '_', $this->fieldname)),
					'value', 'text',
					((string) false)
				);

				$j2c_tmp->class = (string) '';
				$j2c_tmp->onclick = (string) '';

				$options[] = $j2c_tmp;

			}
		}

		reset($options);

		return $options;
	}
}


